package com.ynet.life.util;

import java.io.BufferedReader;
import java.io.EOFException;
import java.io.FileReader;
import java.io.IOException;
import java.io.Reader;
import java.util.Vector;

/* loaded from: com_ynet_life_util.jar:com/ynet/life/util/CSVReader.class */
public class CSVReader {
    private static final boolean debugging = true;
    private BufferedReader r;
    private char separator;
    private static final int EOL = 0;
    private static final int ORDINARY = 1;
    private static final int QUOTE = 2;
    private static final int SEPARATOR = 3;
    private static final int WHITESPACE = 4;
    private static final int SEEKINGSTART = 0;
    private static final int INPLAIN = 1;
    private static final int INQUOTED = 2;
    private static final int AFTERENDQUOTE = 3;
    private static final int SKIPPINGTAIL = 4;
    private String line = null;
    private int lineCount = 0;

    public CSVReader(Reader r, char separator) {
        if (r instanceof BufferedReader) {
            this.r = (BufferedReader) r;
        } else {
            this.r = new BufferedReader(r);
        }
        this.separator = separator;
    }

    public CSVReader(Reader r) {
        if (r instanceof BufferedReader) {
            this.r = (BufferedReader) r;
        } else {
            this.r = new BufferedReader(r);
        }
        this.separator = ',';
    }

    private int categorise(char c) {
        switch (c) {
            case '\n':
            case '#':
                return 0;
            case '\r':
            case ' ':
            case 255:
                return 4;
            case '\"':
                return 2;
            default:
                if (c == this.separator) {
                    return 3;
                }
                if ('!' <= c && c <= '~') {
                    return 1;
                }
                if ((c >= 0 && c <= ' ') || Character.isWhitespace(c)) {
                    return 4;
                }
                return 1;
        }
    }

    public String[] getLine() {
        Vector lineArray = new Vector();
        while (lineArray.size() == 0) {
            try {
                while (true) {
                    String token = get();
                    if (token == null) {
                        break;
                    }
                    lineArray.add(token);
                }
            } catch (EOFException unused) {
                return null;
            } catch (IOException unused2) {
            }
        }
        String[] returnArray = new String[lineArray.size()];
        for (int ii = 0; ii < lineArray.size(); ii++) {
            returnArray[ii] = lineArray.elementAt(ii).toString();
        }
        return returnArray;
    }

    private String get() throws EOFException, IOException {
        StringBuffer field = new StringBuffer(50);
        readLine();
        int state = 0;
        for (int i = 0; i < this.line.length(); i++) {
            char c = this.line.charAt(i);
            int category = categorise(c);
            switch (state) {
                case 0:
                    switch (category) {
                        case 0:
                            this.line = null;
                            return null;
                        case 1:
                            field.append(c);
                            state = 1;
                            break;
                        case 2:
                            state = 2;
                            break;
                        case SqlDateTime.DAY /* 3 */:
                            this.line = this.line.substring(i + 1);
                            return "";
                    }
                case 1:
                    switch (category) {
                        case 0:
                            this.line = this.line.substring(i);
                            return field.toString().trim();
                        case 1:
                            field.append(c);
                            break;
                        case 2:
                            throw new IOException("Malformed CSV stream. Missing quote at start of field on line " + this.lineCount);
                        case SqlDateTime.DAY /* 3 */:
                            this.line = this.line.substring(i + 1);
                            return field.toString().trim();
                        case 4:
                            field.append(' ');
                            break;
                    }
                case 2:
                    switch (category) {
                        case 0:
                            throw new IOException("Malformed CSV stream. Missing quote after field on line " + this.lineCount);
                        case 1:
                        case SqlDateTime.DAY /* 3 */:
                            field.append(c);
                            break;
                        case 2:
                            state = 3;
                            break;
                        case 4:
                            field.append(' ');
                            break;
                    }
                case SqlDateTime.DAY /* 3 */:
                    switch (category) {
                        case 0:
                            this.line = this.line.substring(i);
                            return field.toString().trim();
                        case 1:
                            throw new IOException("Malformed CSV stream, missing separator after field on line " + this.lineCount);
                        case 2:
                            field.append(c);
                            state = 2;
                            break;
                        case SqlDateTime.DAY /* 3 */:
                            this.line = this.line.substring(i + 1);
                            return field.toString().trim();
                        case 4:
                            state = 4;
                            break;
                    }
                case 4:
                    switch (category) {
                        case 0:
                            this.line = this.line.substring(i);
                            return field.toString().trim();
                        case 1:
                        case 2:
                            throw new IOException("Malformed CSV stream, missing separator after field on line " + this.lineCount);
                        case SqlDateTime.DAY /* 3 */:
                            this.line = this.line.substring(i + 1);
                            return field.toString().trim();
                    }
            }
        }
        throw new IOException("Program logic bug. Should not reach here. Processing line " + this.lineCount);
    }

    private void readLine() throws EOFException, IOException {
        if (this.line == null) {
            this.line = this.r.readLine();
            if (this.line == null) {
                throw new EOFException();
            }
            this.line = String.valueOf(this.line) + '\n';
            this.lineCount++;
        }
    }

    public void skip(int fields) throws EOFException, IOException {
        if (fields <= 0) {
            return;
        }
        for (int i = 0; i < fields; i++) {
            get();
        }
    }

    public void skipToNextLine() throws EOFException, IOException {
        if (this.line == null) {
            readLine();
        }
        this.line = null;
    }

    public void close() throws IOException {
        if (this.r != null) {
            this.r.close();
            this.r = null;
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v0, types: [java.io.IOException] */
    /* JADX WARN: Type inference failed for: r0v2, types: [com.ynet.life.util.CSVReader] */
    /* JADX WARN: Type inference failed for: r0v3 */
    /* JADX WARN: Type inference failed for: r0v4, types: [com.ynet.life.util.CSVReader] */
    /* JADX WARN: Type inference failed for: r0v5, types: [java.io.PrintStream] */
    private static void testSingleTokens(String[] args) {
        ?? r0;
        try {
            r0 = new CSVReader(new FileReader(args[0]), ',');
            while (true) {
                try {
                    r0 = System.out;
                    r0.println(r0.get());
                } catch (EOFException unused) {
                    r0 = r0;
                    r0.close();
                    return;
                }
            }
        } catch (IOException e) {
            r0.printStackTrace();
            System.out.println(e.getMessage());
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v0, types: [java.lang.String] */
    /* JADX WARN: Type inference failed for: r0v1, types: [java.io.IOException] */
    /* JADX WARN: Type inference failed for: r0v6, types: [com.ynet.life.util.CSVReader] */
    private static void testLines(String[] args) {
        ?? r0 = ",";
        try {
            CSVReader csv = new CSVReader(new FileReader(args[0]), ',');
            while (true) {
                String[] loadLine = csv.getLine();
                if (loadLine != null) {
                    StringBuffer logBuffer = new StringBuffer();
                    logBuffer.append(loadLine[0]);
                    for (int i = 1; i < loadLine.length; i++) {
                        logBuffer.append(",").append(loadLine[i]);
                    }
                    String logLine = logBuffer.toString();
                    System.out.println(logLine);
                } else {
                    r0 = csv;
                    r0.close();
                    return;
                }
            }
        } catch (IOException e) {
            r0.printStackTrace();
            System.out.println(e.getMessage());
        }
    }

    public static void main(String[] args) {
        testSingleTokens(args);
        testLines(args);
    }
}
